@@ -2,10 +2,22 @@ package TestCGIBin::Controller::CGIHandler;
 
 use parent 'Catalyst::Controller::CGIBin';
 
+# Turn off log for the non-zero exit test
+sub auto : Private {
+    my ($self, $c) = @_;
+    $c->log->levels() unless $c->debug;
+    1;
+}
+
+sub cgi_path {
+    my ($self, $cgi) = @_;
+    return "my-bin/$cgi";
+}
+
 # try out a forward
 sub dongs : Local Args(0) {
     my ($self, $c) = @_;
-    $c->forward('/cgihandler/CGI_path_test_pl');
+    $c->forward('/cgihandler/CGI_path__test_pl');
 }
 
 # try resolved forward
